-----------------------------------------------------------------------------

if not Aloft or not Aloft:HasModule("Polymorph") then return end
local AloftPolymorph = Aloft:GetModule("Polymorph")

local L = AceLibrary("AceLocale-2.2"):new("AloftPolymorphOptions")
local SML = AceLibrary("SharedMedia-1.0")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Polymorph"] = true,
	["Polymorph options"] = true,

	["Enable"] = true,
	["Shows polymorph timers on nameplates when possible"] = true,
	["Speculative Attach"] = true,
	["Attempt to attach the polymorph timer bar when it is not absolutely certain if it is the correct nameplate"] = true,
	["Texture"] = true,
	["Sets the polymorph bar texture"] = true,
	["Colors"] = true,
	["Color options"] = true,
	["Bar Color"] = true,
	["Sets the polymorph bar color"] = true,
	["Backdrop Color"] = true,
	["Sets the polymorph backdrop color"] = true,
	["Size"] = true,
	["Polymorph size options"] = true,
	["Width"] = true,
	["Sets the width of the polymorph bar"] = true,
	["Height"] = true,
	["Sets the height of the polymorph bar"] = true,
	["Position"] = true,
	["Adjust polymorph bar position"] = true,
	["Anchor"] = true,
	["Sets the anchor for the polymorph bar"] = true,
	["Anchor To"] = true,
	["Sets the relative point on the health bar to anchor the polymorph bar"] = true,
	["X Offset"] = true,
	["X offset of the polymorph bar"] = true,
	["Y Offset"] = true,
	["Y offset of the polymorph bar"] = true,
} end)

-----------------------------------------------------------------------------

Aloft.Options.args.polymorph =
{
	type = 'group',
	name = L["Polymorph"],
	desc = L["Polymorph options"],
	disabled = function() return not Aloft:IsActive() end,
	args =
	{
		enable =
		{
			type = 'toggle',
			name = L["Enable"],
			desc = L["Shows polymorph timers on nameplates when possible"],
			get = function() return AloftPolymorph.db.profile.enable end,
			set = function(v) AloftPolymorph.db.profile.enable = v AloftPolymorph:UpdateAll() end,
			order = 1
		},
		speculativeAttach =
		{
			type = 'toggle',
			name = L["Speculative Attach"],
			desc = L["Attempt to attach the polymorph timer bar when it is not absolutely certain if it is the correct nameplate"],
			disabled = function() return not AloftPolymorph.db.profile.enable end,
			get = function() return AloftPolymorph.db.profile.speculativeAttach end,
			set = function(v) AloftPolymorph.db.profile.speculativeAttach = v end,
			order = 2
		},
		texture =
		{
			type = "text", 
			name = L["Texture"], 
			desc = L["Sets the polymorph bar texture"],
			disabled = function() return not AloftPolymorph.db.profile.enable end,
			get = function() return AloftPolymorph.db.profile.texture end,
			set = function(v) AloftPolymorph.db.profile.texture = v AloftPolymorph:UpdateAll() end,
			validate = SML_statusbar
		},
		colors =
		{
			type = 'group',
			name = L["Colors"],
			desc = L["Color options"],
			disabled = function() return not AloftPolymorph.db.profile.enable end,
			args =
			{
				bar =
				{
					type = 'color',
					name = L["Bar Color"],
					desc = L["Sets the polymorph bar color"],
					get = function() return unpack(AloftPolymorph.db.profile.color) end,
					set = function(r, g, b, a) AloftPolymorph.db.profile.color = { r, g, b, a } AloftPolymorph:UpdateAll() end,
					hasAlpha = true,
					order = 1
				},
				backdrop =
				{
					type = 'color',
					name = L["Backdrop Color"],
					desc = L["Sets the polymorph backdrop color"],
					get = function() return unpack(AloftPolymorph.db.profile.backdropColor) end,
					set = function(r, g, b, a) AloftPolymorph.db.profile.backdropColor = { r, g, b, a } AloftPolymorph:UpdateAll() end,
					hasAlpha = true,
					order = 2
				},
			},
		},
		size =
		{
			type = 'group',
			name = L["Size"],
			desc = L["Polymorph size options"],
			disabled = function() return not AloftPolymorph.db.profile.enable end,
			args =
			{
				width =
				{
					type = 'range',
					name = L["Width"],
					desc = L["Sets the width of the polymorph bar"],
					min = 5,
					max = 250,
					step = 1,
					get = function() return AloftPolymorph.db.profile.width end,
					set = function(v) AloftPolymorph.db.profile.width = v AloftPolymorph:UpdateAll() end
				},
				height =
				{
					type = 'range',
					name = L["Height"],
					desc = L["Sets the height of the polymorph bar"],
					min = 2,
					max = 32,
					step = 1,
					get = function() return AloftPolymorph.db.profile.height end,
					set = function(v) AloftPolymorph.db.profile.height = v AloftPolymorph:UpdateAll() end
				},
			},
		},
		position =
		{
			type = 'group',
			name = L["Position"],
			desc = L["Adjust polymorph bar position"],
			disabled = function() return not AloftPolymorph.db.profile.enable end,
			args =
			{
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the polymorph bar"],
					get = function() return AloftPolymorph.db.profile.point end,
					set = function(v) AloftPolymorph.db.profile.point = v AloftPolymorph:UpdateAll() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the polymorph bar"],
					get = function() return AloftPolymorph.db.profile.relativeToPoint end,
					set = function(v) AloftPolymorph.db.profile.relativeToPoint = v AloftPolymorph:UpdateAll() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the polymorph bar"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return AloftPolymorph.db.profile.offsetX end,
					set = function(v) AloftPolymorph.db.profile.offsetX = v AloftPolymorph:UpdateAll() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the polymorph bar"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return AloftPolymorph.db.profile.offsetY end,
					set = function(v) AloftPolymorph.db.profile.offsetY = v AloftPolymorph:UpdateAll() end
				},
			},
		},
	},
}

-----------------------------------------------------------------------------
